==> environment_config-1.0.0.tar.gz: lib/config.dart <==
import 'package:args/args.dart';
import 'package:code_builder/code_builder.dart';

import 'errors/validation_error.dart';
import 'config_field_type.dart';

final RegExp _PATTERN_REGEXP = RegExp(r'__VALUE__');

class Config {

  final ArgResults arguments;
  final Map<dynamic, dynamic> config;

  Config(this.config, this.arguments);

  String get filePath {
    return 'lib/${_getConfigValue(ConfigFieldType.PATH, 'environment_config.dart')}';
  }

  String get dotEnvFilePath {
    return 'lib/${_getConfigValue(ConfigFieldType.DOTENV_PATH, '.env')}';
  }

  String get className {
    String className = _getConfigValue(ConfigFieldType.CLASS);

    if (className != null) {
      return className;
    }

    final String fileName = RegExp(r'\/([\w_-]+)\.dart$').firstMatch(filePath).group(1);

    return fileName.split('_')
        .map((s) => '${s[0].toUpperCase()}${s.substring(1)}')
        .join('');
  }

  Iterable<FieldConfig> get fields {
    final Map<dynamic, dynamic> fields = config[ConfigFieldType.FIELDS];

    return fields.keys.map((key) => FieldConfig(
      key,
      config[ConfigFieldType.FIELDS][key] ?? {},
      arguments[key]
    ));
  }

  Iterable<FieldConfig> get dotEnvFields {
    return fields.where((field) => field.isDotEnv);
  }

  Iterable<String> get imports {
    if (!config.containsKey(ConfigFieldType.IMPORTS)) {
      return [];
    }

    final List<dynamic> imports = config[ConfigFieldType.IMPORTS];

    return imports?.map((f) => f as String) ?? [];
  }

  bool get isClassConst {
    if (config.containsKey(ConfigFieldType.CONST)) {
      return config[ConfigFieldType.CONST];
    }

    return fields.every((field) => field.isConst);
  }

  bool get createDotEnv => dotEnvFields.length > 0;

  String _getConfigValue(key, [String defaultValue]) {
    if (arguments.arguments.contains(key) && !arguments[key].isEmpty) {
      return arguments[key];
    }

    if (config.containsKey(key) && !(config[key] ?? '').isEmpty) {
      return config[key];
    }

    return defaultValue;
  }
}

class FieldConfig {

  final String name;
  final Map<dynamic, dynamic> field;
  final String _value;

  FieldConfig(this.name, this.field, [String value]): _value = value {
    if ((_value ?? field[ConfigFieldType.DEFAULT] ?? '').isEmpty) {
      throw ValidationError(name, '"$name" is required');
    }
  }

  String get type => field[ConfigFieldType.TYPE] ?? 'String';

  FieldModifier get modifier {
    if (isConst) {
      return FieldModifier.constant;
    }

    return FieldModifier.final$;
  }

  bool get isConst => field[ConfigFieldType.CONST] ?? true;
  bool get isDotEnv => field[ConfigFieldType.IS_DOTENV] ?? false;

  String get value {
    String pattern = _pattern;

    if (_pattern == null && type == 'String') {
      pattern = '\'__VALUE__\'';
    }

    if (pattern == null) {
      return _fieldValue;
    }

    return pattern.replaceAll(_PATTERN_REGEXP, _fieldValue);
  }

  String get dotEnvValue {
    return _pattern?.replaceAll(_PATTERN_REGEXP, _fieldValue) ?? _fieldValue;
  }

  String get _pattern => field[ConfigFieldType.PATTERN];

  String get _fieldValue => _value ?? field[ConfigFieldType.DEFAULT];
}

==> environment_config-1.1.0.tar.gz: lib/config.dart <==
import 'package:args/args.dart';
import 'package:code_builder/code_builder.dart';

import 'errors/validation_error.dart';
import 'config_field_type.dart';

final RegExp _PATTERN_REGEXP = RegExp(r'__VALUE__');

/// Config object that provides parsed
/// params from command
class Config {
  /// Arguments from command
  final ArgResults arguments;

  /// Config object from yaml file
  final Map<dynamic, dynamic> config;

  Config(this.config, this.arguments);

  /// Target file for generated config class
  String get filePath {
    return 'lib/${_getConfigValue(ConfigFieldType.PATH, 'environment_config.dart')}';
  }

  /// Target file for `.env` params
  String get dotEnvFilePath {
    return 'lib/${_getConfigValue(ConfigFieldType.DOTENV_PATH, '.env')}';
  }

  /// Provides config class name
  String get className {
    String className = _getConfigValue(ConfigFieldType.CLASS);

    if (className != null) {
      return className;
    }

    final String fileName =
        RegExp(r'\/([\w_-]+)\.dart$').firstMatch(filePath).group(1);

    return fileName
        .split('_')
        .map((s) => '${s[0].toUpperCase()}${s.substring(1)}')
        .join('');
  }

  /// Field configurations for config class
  Iterable<FieldConfig> get fields {
    final Map<dynamic, dynamic> fields = config[ConfigFieldType.FIELDS];

    return fields.keys.map((key) => FieldConfig(
      key,
      config[ConfigFieldType.FIELDS][key] ?? {},
      arguments[key]
    ));
  }

  /// Fields, that should be exported to `.env` file
  Iterable<FieldConfig> get dotEnvFields {
    return fields.where((field) => field.isDotEnv);
  }

  /// Collection if imports, that should be added to config class
  Iterable<String> get imports {
    if (!config.containsKey(ConfigFieldType.IMPORTS)) {
      return [];
    }

    final List<dynamic> imports = config[ConfigFieldType.IMPORTS];

    return imports?.map((f) => f as String) ?? [];
  }

  /// If class should contain `const` constructor
  ///
  /// In can be forced to be true with yaml config
  ///
  /// If config key not specified, class will have const constructor
  /// if all fields are `const`
  bool get isClassConst {
    if (config.containsKey(ConfigFieldType.CONST)) {
      return config[ConfigFieldType.CONST];
    }

    return fields.every((field) => field.isConst);
  }

  /// Defines if generator should try to create `.env` file
  bool get createDotEnv => dotEnvFields.isNotEmpty;

  String _getConfigValue(key, [String defaultValue]) {
    if (arguments.arguments.contains(key) && !arguments[key].isEmpty) {
      return arguments[key];
    }

    if (config.containsKey(key) && !(config[key] ?? '').isEmpty) {
      return config[key];
    }

    return defaultValue;
  }
}

class FieldConfig {
  /// Field name
  final String name;

  /// Field configuration from YAML file
  final Map<dynamic, dynamic> field;

  /// Value provided from command params
  final String _value;

  FieldConfig(this.name, this.field, [String value]) : _value = value {
    if ((_value ?? field[ConfigFieldType.DEFAULT]) == null) {
      throw ValidationError(name, '"$name" is required');
    }
  }

  /// Field type
  ///
  /// Default to `String`
  String get type => field[ConfigFieldType.TYPE] ?? 'String';

  /// Field modifier
  ///
  /// If field is `const` provides Field builder modifier
  FieldModifier get modifier {
    if (isConst) {
      return FieldModifier.constant;
    }

    return FieldModifier.final$;
  }

  /// Defines if field should be `const` or not
  ///
  /// If key not specified field will be treated as `const` by default
  bool get isConst => field[ConfigFieldType.CONST] ?? true;

  /// Defines if this field should be exported to `.env` file
  bool get isDotEnv => field[ConfigFieldType.IS_DOTENV] ?? false;

  /// Get value for config class
  ///
  /// If `pattern` is specified, value will injected into it
  String get value {
    String pattern = _pattern;

    if (_pattern == null && type == 'String') {
      pattern = '\'__VALUE__\'';
    }

    if (pattern == null) {
      return _fieldValue;
    }

    return pattern.replaceAll(_PATTERN_REGEXP, _fieldValue);
  }

  /// Value for key in `.env` file
  String get dotEnvValue {
    return _pattern?.replaceAll(_PATTERN_REGEXP, _fieldValue) ?? _fieldValue;
  }

  String get _pattern => field[ConfigFieldType.PATTERN];

  String get _fieldValue => _value ?? field[ConfigFieldType.DEFAULT];
}
